=======
Credits
=======

Initial Author
--------------

* Kirill Klenov <horneds@gmail.com>


Development Lead
----------------

* spumer

Contributors
------------

* Channel Cat (https://github.com/channelcat)
* Dima Kurguzov (https://github.com/koorgoo)
* Dominik Kapisinsky (https://github.com/kapucko)
* Eric Tang (https://github.com/EenTang)
* Hari Jiang (https://github.com/jjyr)
* Matt Riggott (https://github.com/flother)
* Michael Lavers (https://github.com/kolanos)
* Nick Shobe (https://github.com/dingus9)
* Nikita (https://github.com/demty)
* Nils Werner (https://github.com/NilsJPWerner)
* Vladimir Petrov (https://github.com/petrov-vova)
